@@ -9,10 +9,13 @@ describe DataObjects::Reader do
 
     reader = command.execute_reader
 
-    reader.should respond_to(:close)
-    reader.should respond_to(:next!)
-    reader.should respond_to(:values)
-    reader.should respond_to(:fields)
+    reader.should.be.kind_of(Enumerable)
+
+    reader.should.respond_to(:close)
+    reader.should.respond_to(:next!)
+    reader.should.respond_to(:values)
+    reader.should.respond_to(:fields)
+    reader.should.respond_to(:each)
 
     connection.close
   end
